@@ -88,7 +88,8 @@ AddConstraintActivityPreferredStartingTimesForm::AddConstraintActivityPreferredS
 	}
 	activityTagsComboBox->setCurrentIndex(0);
 
-	studentsComboBox->addItem("");
+	populateStudentsComboBox(studentsComboBox, QString(""), true);
+	/*studentsComboBox->addItem("");
 	for(int i=0; i<gt.rules.yearsList.size(); i++){
 		StudentsYear* sty=gt.rules.yearsList[i];
 		studentsComboBox->addItem(sty->name);
@@ -100,7 +101,7 @@ AddConstraintActivityPreferredStartingTimesForm::AddConstraintActivityPreferredS
 				studentsComboBox->addItem(sts->name);
 			}
 		}
-	}
+	}*/
 	studentsComboBox->setCurrentIndex(0);
 	
 	updateActivitiesComboBox();
@@ -367,7 +368,7 @@ void AddConstraintActivityPreferredStartingTimesForm::addConstraint()
 				return;
 	}
 
-	/*foreach(TimeConstraint* tc, gt.rules.timeConstraintsList){
+	/*for(TimeConstraint* tc : qAsConst(gt.rules.timeConstraintsList)){
 		if(tc->type==CONSTRAINT_ACTIVITY_PREFERRED_STARTING_TIMES){
 			ConstraintActivityPreferredStartingTimes* c=(ConstraintActivityPreferredStartingTimes*) tc;
 			if(c->activityId==id){
