@@ -188,6 +188,12 @@ void AddConstraintMinDaysBetweenActivitiesForm::addConstraint()
 			tr("Invalid weight (percentage)"));
 		return;
 	}
+	
+	if(minDaysSpinBox->value()<=0){
+		QMessageBox::warning(this, tr("FET information"),
+			tr("Invalid number of min days between activities - it must be greater than 0."));
+		return;
+	}
 
 	if(this->selectedActivitiesList.count()==0){
 		QMessageBox::warning(this, tr("FET information"),
