@@ -48,7 +48,7 @@ AddConstraintTeacherActivityTagMaxHoursContinuouslyForm::AddConstraintTeacherAct
 	}
 	
 	activityTagsComboBox->clear();
-	foreach(ActivityTag* at, gt.rules.activityTagsList)
+	for(ActivityTag* at : qAsConst(gt.rules.activityTagsList))
 		activityTagsComboBox->addItem(at->name);
 
 	constraintChanged();
