@@ -53,7 +53,7 @@ ConstraintStudentsActivityTagMaxHoursContinuouslyForm::ConstraintStudentsActivit
 	
 	activityTagsComboBox->clear();
 	activityTagsComboBox->addItem("");
-	foreach(ActivityTag* at, gt.rules.activityTagsList)
+	for(ActivityTag* at : qAsConst(gt.rules.activityTagsList))
 		activityTagsComboBox->addItem(at->name);
 
 	this->filterChanged();
