@@ -36,6 +36,16 @@ ModifyConstraintSubactivitiesPreferredStartingTimesForm::ModifyConstraintSubacti
 {
 	setupUi(this);
 
+	int duration=ctr->duration;
+	durationCheckBox->setChecked(duration>=1);
+	durationSpinBox->setEnabled(duration>=1);
+	durationSpinBox->setMinimum(1);
+	durationSpinBox->setMaximum(gt.rules.nHoursPerDay);
+	if(duration>=1)
+		durationSpinBox->setValue(duration);
+	else
+		durationSpinBox->setValue(1);
+
 	okPushButton->setDefault(true);
 
 	connect(preferredTimesTable, SIGNAL(itemClicked(QTableWidgetItem*)), this, SLOT(itemClicked(QTableWidgetItem*)));
@@ -233,7 +243,8 @@ void ModifyConstraintSubactivitiesPreferredStartingTimesForm::updateTeachersComb
 }
 
 void ModifyConstraintSubactivitiesPreferredStartingTimesForm::updateStudentsComboBox(QWidget* parent){
-	int i=0, j=-1;
+	int j=populateStudentsComboBox(studentsComboBox, this->_ctr->studentsName, true);
+	/*int i=0, j=-1;
 	studentsComboBox->clear();
 	studentsComboBox->addItem("");
 	if(this->_ctr->studentsName=="")
@@ -259,7 +270,7 @@ void ModifyConstraintSubactivitiesPreferredStartingTimesForm::updateStudentsComb
 				i++;
 			}
 		}
-	}
+	}*/
 	if(j<0)
 		showWarningForInvisibleSubgroupConstraint(parent, this->_ctr->studentsName);
 	else
@@ -305,6 +316,12 @@ void ModifyConstraintSubactivitiesPreferredStartingTimesForm::updateActivityTags
 
 void ModifyConstraintSubactivitiesPreferredStartingTimesForm::ok()
 {
+	int duration=-1;
+	if(durationCheckBox->isChecked()){
+		assert(durationSpinBox->isEnabled());
+		duration=durationSpinBox->value();
+	}
+
 	if(studentsComboBox->currentIndex()<0){
 		showWarningCannotModifyConstraintInvisibleSubgroupConstraint(this, this->_ctr->studentsName);
 		return;
@@ -369,6 +386,8 @@ void ModifyConstraintSubactivitiesPreferredStartingTimesForm::ok()
 	this->_ctr->days_L=days_L;
 	this->_ctr->hours_L=hours_L;
 
+	this->_ctr->duration=duration;
+
 	gt.rules.internalStructureComputed=false;
 	setRulesModifiedAndOtherThings(&gt.rules);
 	
@@ -380,5 +399,10 @@ void ModifyConstraintSubactivitiesPreferredStartingTimesForm::cancel()
 	this->close();
 }
 
+void ModifyConstraintSubactivitiesPreferredStartingTimesForm::on_durationCheckBox_toggled()
+{
+	durationSpinBox->setEnabled(durationCheckBox->isChecked());
+}
+
 #undef YES
 #undef NO
